@@ -18,11 +18,11 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-import codegen
 import os
 import re
 import sys
 import unittest
+from astor import codegen
 
 
 try:
